@@ -1,12 +1,14 @@
 import os
 from django.core.files.storage import Storage
+from django.conf import settings
 from celery import task
 from .signals import transaction_signals
 
 
 @task
 def delete_file(filename):
-    os.remove(filename)
+    media = getattr(settings, 'MEDIA_ROOT', None)
+    os.remove(os.path.join(media, filename))
 
 
 class DelayHook(Storage):
@@ -21,16 +23,25 @@ class DelayHook(Storage):
     def delete(self, name):
         self.delete_on_commit.append(name)
 
+    def delete_instantly(self, name):
+        return self.storage.delete(name)
+
     def _save(self, name, content):
         self.delete_on_rollback.append(name)
         return self.storage.save(name, content)
 
     def _open(self, name, mode):
-        self.storage.open(name, mode)
+        return self.storage.open(name, mode)
 
     def exists(self, name):
         return self.storage.exists(name)
 
+    def size(self, name):
+        return self.storage.size(name)
+
+    def get_avaiable_name(self, name):
+        return self.storage.get_avaiable_name(name)
+
     def on_commit(self):
         for f in self.delete_on_commit:
             delete_file.delay(f)
